@@ -118,6 +118,7 @@ public class SNMPAgentTest extends JFrame
         this.getRootPane().setBorder(new BevelBorder(BevelBorder.RAISED));
         
         // set fonts to smaller-than-normal size, for compaction!
+        /*
         FontUIResource appFont = new FontUIResource("SansSerif", Font.PLAIN, 10);
         UIDefaults defaults = UIManager.getLookAndFeelDefaults();
         Enumeration keys = defaults.keys();
@@ -130,6 +131,7 @@ public class SNMPAgentTest extends JFrame
                 UIManager.put(nextKey, appFont);
             }
         }
+        */
         
         // add WindowCloseAdapter to catch window close-box closings
         addWindowListener(new WindowCloseAdapter());
@@ -641,8 +643,8 @@ public class SNMPAgentTest extends JFrame
         {
             SNMPAgentTest theApp = new SNMPAgentTest();
             theApp.pack();
-            theApp.setSize(600,500);
-            theApp.show();
+            theApp.setSize(700,500);
+            theApp.setVisible(true);
         }
         catch (Exception e)
         {}
