@@ -95,6 +95,7 @@ public class SNMPInquisitor extends JFrame
         this.getRootPane().setBorder(new BevelBorder(BevelBorder.RAISED));
         
         // set fonts to smaller-than-normal size, for compaction!
+        /*
         FontUIResource appFont = new FontUIResource("SansSerif", Font.PLAIN, 10);
         UIDefaults defaults = UIManager.getLookAndFeelDefaults();
         Enumeration keys = defaults.keys();
@@ -107,7 +108,7 @@ public class SNMPInquisitor extends JFrame
                 UIManager.put(nextKey, appFont);
             }
         }
-        
+        */
         
         // add WindowCloseAdapter to catch window close-box closings
         addWindowListener(new WindowCloseAdapter());
@@ -740,11 +741,13 @@ public class SNMPInquisitor extends JFrame
         {
             SNMPInquisitor theApp = new SNMPInquisitor();
             theApp.pack();
-            theApp.setSize(600,500);
-            theApp.show();
+            theApp.setSize(700,500);
+            theApp.setVisible(true);
         }
         catch (Exception e)
-        {}
+        {
+            System.out.println("Exception starting app: " + e.toString());
+        }
     }
     
 
