@@ -37,6 +37,7 @@ import javax.swing.border.*;
 import javax.swing.plaf.*;
 import java.awt.event.*;
 import java.io.*;
+
 import snmp.*;
 
 
@@ -46,7 +47,9 @@ public class SNMPTrapTest extends JFrame
                             implements ActionListener, SNMPv1TrapListener, SNMPv2TrapListener, SNMPv2InformRequestListener, Runnable
 {
     
-    JButton sendv1TrapButton, sendv2TrapButton, sendv2InformRequestButton;
+    private static final long serialVersionUID = 3046898865193941872L;
+    
+    JButton sendv1TrapButton, sendv2TrapButton, sendv2InformRequestButton, receiveButton;
     JButton clearButton;
     JTextArea messagesArea;
     JScrollPane messagesScroll;
@@ -119,6 +122,7 @@ public class SNMPTrapTest extends JFrame
         this.getRootPane().setBorder(new BevelBorder(BevelBorder.RAISED));
         
         // set fonts to smaller-than-normal size, for compaction!
+        /*
         FontUIResource appFont = new FontUIResource("SansSerif", Font.PLAIN, 10);
         UIDefaults defaults = UIManager.getLookAndFeelDefaults();
         Enumeration keys = defaults.keys();
@@ -131,6 +135,7 @@ public class SNMPTrapTest extends JFrame
                 UIManager.put(nextKey, appFont);
             }
         }
+        */
         
         
         // add WindowCloseAdapter to catch window close-box closings
@@ -190,6 +195,10 @@ public class SNMPTrapTest extends JFrame
         sendv2InformRequestButton.setActionCommand("send v2 inform request");
         sendv2InformRequestButton.addActionListener(this);
         
+        receiveButton = new JButton("Stop receiving");
+        receiveButton.setActionCommand("stop receiving");
+        receiveButton.addActionListener(this);
+        
         clearButton = new JButton("Clear messages");
         clearButton.setActionCommand("clear messages");
         clearButton.addActionListener(this);
@@ -276,6 +285,11 @@ public class SNMPTrapTest extends JFrame
         theLayout.setConstraints(sendv2InformRequestButton, c);
         buttonPanel.add(sendv2InformRequestButton);
         
+        c.gridx = 4;
+        c.gridy = 1;
+        theLayout.setConstraints(receiveButton, c);
+        buttonPanel.add(receiveButton);
+        
         JPanel hostPanel = new JPanel();
         hostPanel.setLayout(theLayout);
         
@@ -476,17 +490,40 @@ public class SNMPTrapTest extends JFrame
         }
         
         
+        
+        if (command == "stop receiving")
+        {
+            try
+            {
+                trapReceiverInterface.stopReceiving();
+            }
+            catch (SocketException e)
+            {
+                System.out.println("Got socket exception");
+            }
+            receiveButton.setText("Start receiving");
+            receiveButton.setActionCommand("start receiving");
+        }
+        
+        
+        
+        if (command == "start receiving")
+        {
+            trapReceiverInterface.startReceiving();
+            receiveButton.setText("Stop receiving");
+            receiveButton.setActionCommand("stop receiving");
+        }
+        
+        
+        
         if (command == "send v1 trap")
         {
             try
             {
             
                 String community = communityField.getText();
-                int version = 0;    // SNMPv1
                 InetAddress hostAddress = InetAddress.getByName(hostIDField.getText());
                 
-                
-                
                 SNMPObjectIdentifier enterpriseOID = new SNMPObjectIdentifier(enterpriseField.getText());
                 SNMPIPAddress agentAddress = new SNMPIPAddress(agentField.getText());
                 int genericTrap = genericTrapBox.getSelectedIndex();
@@ -679,10 +716,11 @@ public class SNMPTrapTest extends JFrame
             
     
     
-    public void processv1Trap(SNMPv1TrapPDU pdu) 
+    public void processv1Trap(SNMPv1TrapPDU pdu, String communityName) 
     {
         messagesArea.append("Got v1 trap:\n");
         
+        messagesArea.append("  community name:     " + communityName + "\n");
         messagesArea.append("  enterprise OID:     " + pdu.getEnterpriseOID().toString() + "\n");
         messagesArea.append("  agent address:      " + pdu.getAgentAddress().toString() + "\n");
         messagesArea.append("  generic trap:       " + pdu.getGenericTrap() + "\n");
@@ -696,10 +734,12 @@ public class SNMPTrapTest extends JFrame
     
     
     
-    public void processv2Trap(SNMPv2TrapPDU pdu) 
+    public void processv2Trap(SNMPv2TrapPDU pdu, String communityName, InetAddress agentIPAddress) 
     {
         messagesArea.append("Got v2 trap:\n");
         
+        messagesArea.append("  agent IP address:   " + agentIPAddress.getHostAddress() + "\n");
+        messagesArea.append("  community name:     " + communityName + "\n");
         messagesArea.append("  system uptime:      " + pdu.getSysUptime().toString() + "\n");
         messagesArea.append("  trap OID:           " + pdu.getSNMPTrapOID().toString() + "\n");
         messagesArea.append("  var bind list:      " + pdu.getVarBindList().toString() + "\n");
@@ -710,10 +750,12 @@ public class SNMPTrapTest extends JFrame
     
     
     
-    public void processv2InformRequest(SNMPv2InformRequestPDU pdu) 
+    public void processv2InformRequest(SNMPv2InformRequestPDU pdu, String communityName, InetAddress agentIPAddress) 
     {
         messagesArea.append("Got v2 inform request:\n");
         
+        messagesArea.append("  sender IP address:  " + agentIPAddress.getHostAddress() + "\n");
+        messagesArea.append("  community name:     " + communityName + "\n");
         messagesArea.append("  system uptime:      " + pdu.getSysUptime().toString() + "\n");
         messagesArea.append("  trap OID:           " + pdu.getSNMPTrapOID().toString() + "\n");
         messagesArea.append("  var bind list:      " + pdu.getVarBindList().toString() + "\n");
@@ -757,8 +799,8 @@ public class SNMPTrapTest extends JFrame
         {
             SNMPTrapTest theApp = new SNMPTrapTest();
             theApp.pack();
-            theApp.setSize(600,500);
-            theApp.show();
+            theApp.setSize(700,500);
+            theApp.setVisible(true);
         }
         catch (Exception e)
         {}
