@@ -37,12 +37,16 @@ import java.net.*;
 /**
 *    The class SNMPv1CommunicationInterface defines methods for communicating with SNMP entities.
 *    The approach is that from version 1 of SNMP, using no encryption of data. Communication occurs
-*    via UDP, using port 161, the standard SNMP port.
+*    via UDP, using port 161, the standard SNMP port, unless an alternate (non-standard) port is
+*    supplied in the constructor.
 */
 
 public class SNMPv1CommunicationInterface
 {
-    public static final int SNMPPORT = 161;
+    public static final int SNMP_PORT = 161;
+    
+    // port to which requests will be sent
+    private int remotePort = SNMP_PORT;
     
     // largest size for datagram packet payload; based on
     // RFC 1157, need to handle messages of at least 484 bytes
@@ -67,16 +71,31 @@ public class SNMPv1CommunicationInterface
     public SNMPv1CommunicationInterface(int version, InetAddress hostAddress, String community)
         throws SocketException
     {
-        this.version = version;
-        this.hostAddress = hostAddress;
-        this.community = community;
-        
-        dSocket = new DatagramSocket();
-        dSocket.setSoTimeout(15000);    //15 seconds
+        this(version, hostAddress, community, SNMP_PORT);
     }
     
     
     
+    /**
+     *    Construct a new communication object to communicate with the specified host using the
+     *    given community name, and sending requests to the specified port. The version setting 
+     *    should be either 0 (version 1) or 1 (version 2, a la RFC 1157).
+     */
+     
+     public SNMPv1CommunicationInterface(int version, InetAddress hostAddress, String community, int remotePort)
+         throws SocketException
+     {
+         this.remotePort = remotePort;
+         this.version = version;
+         this.hostAddress = hostAddress;
+         this.community = community;
+         
+         dSocket = new DatagramSocket();
+         dSocket.setSoTimeout(15000);    //15 seconds
+     }
+    
+    
+    
     
     /**
     *    Permits setting timeout value for underlying datagram socket (in milliseconds).
@@ -131,7 +150,7 @@ public class SNMPv1CommunicationInterface
         SNMPPDU pdu = new SNMPPDU(SNMPBERCodec.SNMPGETNEXTREQUEST, requestID, errorStatus, errorIndex, varList);
         SNMPMessage message = new SNMPMessage(version, community, pdu);
         byte[] messageEncoding = message.getBEREncoding();
-        DatagramPacket outPacket = new DatagramPacket(messageEncoding, messageEncoding.length, hostAddress, SNMPPORT);
+        DatagramPacket outPacket = new DatagramPacket(messageEncoding, messageEncoding.length, hostAddress, remotePort);
         
         
         dSocket.send(outPacket);
@@ -173,7 +192,7 @@ public class SNMPv1CommunicationInterface
             pdu = new SNMPPDU(SNMPBERCodec.SNMPGETNEXTREQUEST, requestID, errorStatus, errorIndex, varList);
             message = new SNMPMessage(version, community, pdu);
             messageEncoding = message.getBEREncoding();
-            outPacket = new DatagramPacket(messageEncoding, messageEncoding.length, hostAddress, SNMPPORT);
+            outPacket = new DatagramPacket(messageEncoding, messageEncoding.length, hostAddress, remotePort);
             
             dSocket.send(outPacket);
             
@@ -241,7 +260,7 @@ public class SNMPv1CommunicationInterface
             System.out.print(hexByte(messageEncoding[i]) + " ");
         */
         
-        DatagramPacket outPacket = new DatagramPacket(messageEncoding, messageEncoding.length, hostAddress, SNMPPORT);
+        DatagramPacket outPacket = new DatagramPacket(messageEncoding, messageEncoding.length, hostAddress, remotePort);
         
         dSocket.send(outPacket);
         
@@ -350,7 +369,7 @@ public class SNMPv1CommunicationInterface
             System.out.print(hexByte(messageEncoding[i]) + " ");
         */
         
-        DatagramPacket outPacket = new DatagramPacket(messageEncoding, messageEncoding.length, hostAddress, SNMPPORT);
+        DatagramPacket outPacket = new DatagramPacket(messageEncoding, messageEncoding.length, hostAddress, remotePort);
         
         
         dSocket.send(outPacket);
@@ -469,7 +488,7 @@ public class SNMPv1CommunicationInterface
             System.out.print(hexByte(messageEncoding[i]) + " ");
         */
         
-        DatagramPacket outPacket = new DatagramPacket(messageEncoding, messageEncoding.length, hostAddress, SNMPPORT);
+        DatagramPacket outPacket = new DatagramPacket(messageEncoding, messageEncoding.length, hostAddress, remotePort);
         
         
         dSocket.send(outPacket);
@@ -573,7 +592,7 @@ public class SNMPv1CommunicationInterface
             System.out.print(hexByte(messageEncoding[i]) + " ");
         */
         
-        DatagramPacket outPacket = new DatagramPacket(messageEncoding, messageEncoding.length, hostAddress, SNMPPORT);
+        DatagramPacket outPacket = new DatagramPacket(messageEncoding, messageEncoding.length, hostAddress, remotePort);
         
         
         dSocket.send(outPacket);
@@ -684,12 +703,12 @@ public class SNMPv1CommunicationInterface
         
         for (int i = 0; i < messageEncoding.length; ++i)
         {
-            System.out.print(getHex(messageEncoding[i]) + " ");
+            System.out.print(hexByte(messageEncoding[i]) + " ");
         }
         */
         
         
-        DatagramPacket outPacket = new DatagramPacket(messageEncoding, messageEncoding.length, hostAddress, SNMPPORT);
+        DatagramPacket outPacket = new DatagramPacket(messageEncoding, messageEncoding.length, hostAddress, remotePort);
         
         
         dSocket.send(outPacket);
@@ -826,7 +845,7 @@ public class SNMPv1CommunicationInterface
         */
         
         
-        DatagramPacket outPacket = new DatagramPacket(messageEncoding, messageEncoding.length, hostAddress, SNMPPORT);
+        DatagramPacket outPacket = new DatagramPacket(messageEncoding, messageEncoding.length, hostAddress, remotePort);
         
         dSocket.send(outPacket);
         
@@ -957,7 +976,7 @@ public class SNMPv1CommunicationInterface
             SNMPPDU pdu = new SNMPPDU(SNMPBERCodec.SNMPGETNEXTREQUEST, requestID, errorStatus, errorIndex, varList);
             SNMPMessage message = new SNMPMessage(version, community, pdu);
             byte[] messageEncoding = message.getBEREncoding();
-            DatagramPacket outPacket = new DatagramPacket(messageEncoding, messageEncoding.length, hostAddress, SNMPPORT);
+            DatagramPacket outPacket = new DatagramPacket(messageEncoding, messageEncoding.length, hostAddress, remotePort);
             
             /*
             System.out.println("Request bytes:");
@@ -1072,7 +1091,7 @@ retrievalLoop:
             
             byte[] messageEncoding = message.getBEREncoding();
             
-            DatagramPacket outPacket = new DatagramPacket(messageEncoding, messageEncoding.length, hostAddress, SNMPPORT);
+            DatagramPacket outPacket = new DatagramPacket(messageEncoding, messageEncoding.length, hostAddress, remotePort);
             
             /*
             System.out.println("Request bytes:");
@@ -1207,4 +1226,4 @@ retrievalLoop:
     
     
     
-}
\ No newline at end of file
+}
